import { isNavigationFailure, Router } from 'vue-router';
// import { useUserStoreWidthOut } from '@/store/modules/user';
import { storage } from '@/utils/storage';
import { PageEnum } from '@/enums/pageEnum';
import { useLoadingBar } from 'naive-ui';
import { ACCESS_TOKEN } from '@/store/mutation-types';

const LOGIN_PATH = PageEnum.BASE_LOGIN;

const whitePathList = [LOGIN_PATH]; // no redirect whitelist

const Loading = useLoadingBar();

export function createRouterGuards(router: Router) {
  // const userStore = useUserStoreWidthOut();
  router.beforeEach(async (to, from, next) => {
    console.log('access token');
    Loading && Loading.start();
    if (from.path === LOGIN_PATH && to.name === 'errorPage') {
      next(PageEnum.BASE_HOME);
      return;
    }

    // Whitelist can be directly entered
    if (whitePathList.includes(to.path as PageEnum)) {
      next();
      return;
    }

    const token = storage.get(ACCESS_TOKEN);
    console.log(token, 'access token');
    if (!token) {
      // You can access without permissions. You need to set the routing meta.ignoreAuth to true
      if (to.meta.ignoreAuth) {
        next();
        return;
      }
      // redirect login page
      const redirectData: { path: string; replace: boolean; query?: any } = {
        path: LOGIN_PATH,
        replace: true
      };
      if (to.path) {
        redirectData.query = {
          ...redirectData.query,
          redirect: to.path
        };
      }
      next(redirectData);
      return;
    }

    // await userStore.GetInfo();

    // const redirectPath = (from.query.redirect || to.path) as string;
    // const redirect = decodeURIComponent(redirectPath);
    // const nextData =
    //   to.path === redirect ? { ...to, replace: true } : { path: redirect };
    // next(nextData);
    next();
    Loading && Loading.finish();
  });

  router.afterEach((to, _, failure) => {
    if (isNavigationFailure(failure)) {
      console.log('failed navigation', failure);
    }
    // const asyncRouteStore = useAsyncRouteStoreWidthOut();
    // // 在这里设置需要缓存的组件名称
    // const keepAliveComponents = asyncRouteStore.keepAliveComponents;
    // const currentComName: any = to.matched.find(
    //   item => item.name == to.name
    // )?.name;
    // if (
    //   currentComName &&
    //   !keepAliveComponents.includes(currentComName) &&
    //   to.meta?.keepAlive
    // ) {
    //   // 需要缓存的组件
    //   keepAliveComponents.push(currentComName);
    // } else if (!to.meta?.keepAlive || to.name == 'Redirect') {
    //   // 不需要缓存的组件
    //   const index = asyncRouteStore.keepAliveComponents.findIndex(
    //     name => name == currentComName
    //   );
    //   if (index != -1) {
    //     keepAliveComponents.splice(index, 1);
    //   }
    // }
    // asyncRouteStore.setKeepAliveComponents(keepAliveComponents);
    Loading && Loading.finish();
  });

  // router.onError(error => {});
}
