import { defineComponent, reactive } from 'vue';
import styles from './index.module.less';
import bannerPerson from './images/bannerPerson.png';
import { NIcon, NImage, NDataTable } from 'naive-ui';
import leftDot from './images/leftDot.png';
import rightDot from './images/rightDot.png';
import lineIcon from './images/lineIcon.png';
import musicIcon from './images/musicIcon.png';
import Study from './components/study';
import Pagination from '@/components/pagination';
import headerD from './images/headerD.png';
import defultHeade from '@/components/layout/images/teacherIcon.png';
import cloundIcon from './images/cloundIcon.png';
import goClass from './images/goClass.png';
import boxIcon from './images/boxIcon.png';
import TeachList from './components/teachList';
export default defineComponent({
  name: 'home-page',
  setup() {
    const state = reactive({
      loading: false,
      pagination: {
        page: 1,
        rows: 10,
        pageTotal: 0
      },
      tableList: [] as any
    });
    const columns = () => {
      return [
        {
          title: '布置老师',
          key: 'id'
        },
        {
          title: '布置时间',
          key: 'id'
        },
        {
          title: '截止时间',
          key: 'id'
        },
        {
          title: '训练状态',
          key: 'id'
        },
        {
          title: '布置人数',
          key: 'id'
        },
        {
          title: '提交人数',
          key: 'id'
        },
        {
          title: '合格人数',
          key: 'id'
        },
        {
          title: '提交率',
          key: 'id'
        },
        {
          title: '合格率',
          key: 'id'
        },
        {
          title: '操作',
          key: 'id'
        }
      ];
    };
    const getList = () => {
      console.log('1');
    };
    return () => (
      <div class={styles.homeWrap}>
        <div class={styles.homeInfoLeft}>
          <div class={styles.homeBanner}>
            <img class={styles.bannerPerson} src={bannerPerson}></img>
            <div class={styles.bannerInfo}>
              <h3>Hi，张老师 下午好！</h3>
              <p class={styles.bannerMsg}>
                您有 <span class={styles.bannerRed}> 4 </span>
                <span class={styles.bannerRrey}> 条消息未读，</span>
                <span class={styles.bannerRed}> 3 </span>
                门课程未布置作业，请及时处理哦！
              </p>
              <div class={styles.bannerBtn}>
                立即处理{' '}
                <NIcon class={styles.rotueRight}>
                  <svg
                    xmlns="http://www.w3.org/2000/svg"
                    xmlns:xlink="http://www.w3.org/1999/xlink"
                    viewBox="0 0 24 24">
                    <path
                      d="M7.38 21.01c.49.49 1.28.49 1.77 0l8.31-8.31a.996.996 0 0 0 0-1.41L9.15 2.98c-.49-.49-1.28-.49-1.77 0s-.49 1.28 0 1.77L14.62 12l-7.25 7.25c-.48.48-.48 1.28.01 1.76z"
                      fill="currentColor"></path>
                  </svg>
                </NIcon>
              </div>
            </div>
            <NImage class={styles.leftDot} src={leftDot}></NImage>
            <NImage class={styles.rightDot} src={rightDot}></NImage>
            <NImage class={styles.lineIcon} src={lineIcon}></NImage>
            <NImage class={styles.musicIcon} src={musicIcon}></NImage>
          </div>
          <div class={styles.leftBottomWrap}>
            <Study></Study>
            <div class={styles.tableWrap}>
              <NDataTable
                class={styles.classTable}
                loading={state.loading}
                columns={columns()}
                data={state.tableList}></NDataTable>
              <Pagination
                v-model:page={state.pagination.page}
                v-model:pageSize={state.pagination.rows}
                v-model:pageTotal={state.pagination.pageTotal}
                onList={getList}
                sync
                saveKey="orchestraRegistration-key"
              />
            </div>
          </div>
        </div>
        <div class={styles.homeInfoRight}>
          <div class={styles.homeInfoRightTop}>
            <div class={styles.HeaderWrap}>
              <NImage
                previewDisabled
                class={styles.headerD}
                src={headerD}></NImage>
              <NImage
                previewDisabled
                class={styles.defultHeade}
                src={defultHeade}></NImage>
            </div>
            <div class={styles.headerInfo}>
              <p class={styles.headerTitle}>张晚意</p>
              <p class={styles.headerSubTitle}>武汉小学 | 音乐老师</p>
            </div>
            <div class={styles.quickEnter}>
              <h3 class={styles.rightTitle}>
                <div class={styles.titleDot}></div>快捷入口
              </h3>
              <div class={styles.quickList}>
                <div class={styles.quickItem}>
                  <NImage
                    previewDisabled
                    class={styles.quickItemImg}
                    src={goClass}></NImage>
                  <p>开始上课</p>
                </div>
                <div class={styles.quickItem}>
                  <NImage
                    previewDisabled
                    class={styles.quickItemImg}
                    src={cloundIcon}></NImage>
                  <p>我的资源</p>
                </div>
                <div class={styles.quickItem}>
                  <NImage
                    previewDisabled
                    class={styles.quickItemImg}
                    src={boxIcon}></NImage>
                  <p>工具箱</p>
                </div>
              </div>
            </div>
          </div>
          <div class={styles.rightTeachingWrap}>
            <h3 class={styles.rightTitle}>
              <div class={styles.titleDot}></div>教学进度
            </h3>
            <TeachList></TeachList>
          </div>
        </div>
      </div>
    );
  }
});
