import { defineComponent, reactive, ref } from 'vue';
import loginStyles from './images/login_styles.png';
import lockIcon from './images/lock-icon.png';
import useIcon from './images/user-icon.png';
import openEye from './images/openEye.png';
import closeEye from './images/closeEye.png';
import { PageEnum } from '@/enums/pageEnum';
import {
  useMessage,
  NForm,
  NFormItem,
  NInput,
  NButton,
  NCheckbox
} from 'naive-ui';
import { useUserStore } from '@/store/modules/users';
import styles from './index.module.less';
import { ResultEnum } from '@/enums/httpEnum';
import { useRoute, useRouter } from 'vue-router';
import { storage } from '@/utils/storage';

interface FormState {
  username: string;
  password: string;
  grant_type: string;
  loginType: string;
  client_id: string;
  client_secret: string;
}

export default defineComponent({
  name: 'login-page',
  setup() {
    const router = useRouter();
    const route = useRoute();
    const formRef = ref();
    const message = useMessage();
    console.log(message);
    const loading = ref(false);
    const autoLogin = ref(true);
    const LOGIN_NAME = PageEnum.BASE_LOGIN_NAME;
    const showPwd = ref(false);
    const formInline = reactive({
      username: '',
      password: '',
      isCaptcha: true
    });
    const userStore = useUserStore();

    const handleSubmit = async () => {
      formRef.value.validate(async (errors: any) => {
        if (!errors) {
          const { username, password } = formInline;
          message.loading('登录中...');
          loading.value = true;

          const params: FormState = {
            username,
            password,
            loginType: 'password',
            grant_type: 'password',
            client_id: 'jmedu-backend',
            client_secret: 'jmedu-backend'
          };

          try {
            const some = await userStore.login();
            // return;
            message.destroyAll();
            // if (some.code == ResultEnum.SUCCESS) {
            //  判断是否勾选自动登录
            if (autoLogin.value) {
              storage.set('userInfo', JSON.stringify(formInline));
            } else {
              storage.remove('userInfo');
            }

            // route.query?.redirect ||
            const toPath = decodeURIComponent('/' as string);

            message.success('登录成功，即将进入系统');
            if (route.name === LOGIN_NAME) {
              router.replace('/');
            } else router.replace(toPath);
            // } else {
            //   // message.info(some.msg || "登录失败");
            // }
          } finally {
            loading.value = false;
          }
        }
      });
    };
    return () => (
      <div class={styles['view-account']}>
        <div class={styles['view-account-container']}>
          <div class={styles['stylesWrap']}>
            <img src={loginStyles} alt="" />
          </div>
          <div class={styles['view-account-form']}>
            <div class={styles['view-account-form-wrap']}>
              <div class={styles.formTitle}>
                <div class={styles.dot}></div>
                酷乐秀课堂乐器
              </div>
              <NForm
                ref={formRef}
                label-placement="left"
                size="large"
                model={formInline}>
                <NFormItem
                  path="username"
                  rule={[
                    { required: true, message: '请输入用户名', trigger: 'blur' }
                  ]}>
                  <NInput
                    v-model:value={formInline.username}
                    placeholder="请输入用户名">
                    {{
                      prefix: () => (
                        <img src={useIcon} class={styles.prefixIcon} alt="" />
                      )
                    }}
                  </NInput>
                </NFormItem>
                <NFormItem
                  path="password"
                  rule={[
                    { required: true, message: '请输入密码', trigger: 'blur' }
                  ]}>
                  <NInput
                    v-model:value={formInline.password}
                    type="text"
                    showPasswordOn="click"
                    placeholder="请输入密码"
                    inputProps={{ autocomplete: 'off' }}
                    class={[showPwd.value ? '' : styles['no-pwd']]}
                    onKeydown={(e: KeyboardEvent) => {
                      console.log(e, 'onKeydown');
                      if (e.keyCode === 13) {
                        handleSubmit();
                      }
                    }}>
                    {{
                      prefix: () => (
                        <img src={lockIcon} class={styles.prefixIcon} alt="" />
                      ),
                      suffix: () => (
                        <img
                          src={showPwd.value ? closeEye : openEye}
                          class={styles.pwdIcon}
                          alt=""
                          onClick={() => {
                            showPwd.value = !showPwd.value;
                          }}
                        />
                      )
                    }}
                  </NInput>
                </NFormItem>
                <NFormItem class={styles['default-color']}>
                  <div class={[styles['flex'], styles['justify-between']]}>
                    <div class={styles['flex-initial']}>
                      <NCheckbox v-model:checked={autoLogin.value}>
                        记住密码
                      </NCheckbox>
                    </div>
                  </div>
                </NFormItem>
                <NFormItem>
                  <NButton
                    class={styles.submitBtm}
                    type="primary"
                    onClick={handleSubmit}
                    size="large"
                    loading={loading.value}
                    block>
                    登录
                  </NButton>
                </NFormItem>
              </NForm>
            </div>
          </div>
        </div>
      </div>
    );
  }
});
